@@ -29,7 +29,7 @@ class Order(BaseTradeSQLModel, table=True):
 
     __table_args__ = {'extend_existing': True}
     
-    id: Optional[int] = Field(default=None, primary_key=True)
+    id: Optional[str] = Field(default=None, primary_key=True)
     account: str
     pos_idx: int
     market: str
